# rpc42b2t

![language](https://img.shields.io/badge/language-python-blue)
![python-version](https://img.shields.io/badge/python-%3E%3D3.5-blue)
[![pypresence](https://img.shields.io/badge/using-pypresence-00bb88.svg?style=for-the-badge&logo=discord&logoWidth=20)](https://github.com/qwertyquerty/pypresence)

An improved Discord Rich Presence for 2b2t.org.

## Installation

```sh
pip install rpc42b2t
```

## Usage

Start the game and then run

```sh
rpc42b2t
```

## Future

Possible ways to improve this project:

- refactor code
- make it a Minecraft mod
